package compositeRefactoring.changes;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jdt.core.IJavaElement;
import org.eclipse.jdt.core.IMethod;
import org.eclipse.jdt.core.IType;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.jdt.internal.corext.refactoring.base.Change;
import org.eclipse.jdt.internal.corext.refactoring.base.ChangeAbortException;
import org.eclipse.jdt.internal.corext.refactoring.base.ChangeContext;
import org.eclipse.jdt.internal.corext.refactoring.base.IChange;
import org.eclipse.jdt.internal.corext.refactoring.changes.DeleteSourceManipulationChange;

import compositeRefactoring.codemanipulation.CreateAbstractMethod;
import compositeRefactoring.codemanipulation.FormatCode;

/** This class represents an IChange for the refactoring CreateAbstractMethodRefactoring.
 * It is created when the method CreateAbstractMethodRefactoring.createChange(IProgressMonitor pm) is called.
 * An abstract method (with no body) is created and stored in the parent element, here an IType object.
 */

public class CreateAbstractMethodChange extends Change implements IChange {
	
	private CreateAbstractMethod fCreateAbstractMethod;
	private IMethod fMethod = null;
	private IType fModifiedLanguageElement;
	
	/** creates a new CreateAbstractMethodChange object.
	 * @param parentType the Type in which the new method is to be created.
	 * @param name the name of the abstract method.
	 * @param returnType the return type of the abstract method.
	 * @param parameters the method's parameter. The String array should look like 
	 * {"Object o", "java.util.Vector", "int i"}.
	 */
	public CreateAbstractMethodChange(IType parentType, String name, String returnType, String[] parameters) {
		fModifiedLanguageElement = parentType;
		fCreateAbstractMethod = new CreateAbstractMethod(parentType, name, returnType, parameters, false);
	}
	/** performs the change. When this method is called, a new abstract method is created in the parentType.
	 * The method's declaration is "public abstrac 'methodName'('parameters');".
	 * @param context the change context in which the change is performed
	 * @param pm a progress monitor tracking the changes.
	 */
	public void perform(ChangeContext context, IProgressMonitor pm)
		throws JavaModelException, ChangeAbortException {
		fCreateAbstractMethod.executeOperation();
		IJavaElement[] results = fCreateAbstractMethod.getResultElements();
		if (results.length <= 1) {
			fMethod = (IMethod) results[0];
		}
		else {
			System.out.println(getName() + " is not undoable!!");
		}
		//format the code: doesn't work...
		//FormatCode.formatCode(fModifiedLanguageElement.getCompilationUnit());
	}
	/** gets the undo change. The undo change deletes the created method from the parentType.
	 * @return the undo change.
	 */
	public IChange getUndoChange() {
		return new DeleteSourceManipulationChange(fMethod); 
	}
	/** gets the name of this change.
	 */
	public String getName() {
		return "CreateAbstractMethodChange";
	}
	/** gets the modified language element. In this case, the modified language element is a type.
	 *@return the modified language element.
	 */
	public Object getModifiedLanguageElement() {
		return fModifiedLanguageElement;
	}

}
