package compositeRefactoring.changes;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.jdt.internal.corext.refactoring.base.Change;
import org.eclipse.jdt.internal.corext.refactoring.base.ChangeAbortException;
import org.eclipse.jdt.internal.corext.refactoring.base.ChangeContext;
import org.eclipse.jdt.internal.corext.refactoring.base.IChange;

import compositeRefactoring.codemanipulation.Inherit;

/** This class represents an IChange for the <b>UNDO</b> of the refactoring InheritRefactoring.
 * This Change should not be called by clients. It is only called by the InheritChange.getUndoChange() method.
 */

public class UndoInheritChange extends Change implements IChange {
	
	private Inherit fInherit;
	
	/** creates an UndoInheritChange.
	 * @param change the Inherit object for core operations.
	 */
	public UndoInheritChange(Inherit change) {
		fInherit = change;
	}
	/** performs the change. When this method is called, the base class of the inherit refactoring
	 * does not extend the derived class any longer.
	 * @param context the change context in which the change is performed
	 * @param pm a progress monitor tracking the changes.
	 */
	public void perform(ChangeContext context, IProgressMonitor pm)
		throws JavaModelException, ChangeAbortException {
			
		fInherit.executeUndoOperation();
	}
	/** gets the undo change.
	 * @return an IChange object representing a new inherit change for base, derived.
	 */
	public IChange getUndoChange() {
		return new InheritChange(fInherit.getBase(), fInherit.getDerived(), fInherit);
	}
	/** gets the name of this change.
	 */	
	public String getName() {
		return "UndoInheritChange";
	}
	/** gets the modified language element. In this case, the modified language element is the base class
	 * which inherits from the derived class.
	 * @return the modified language element.
	 */
	public Object getModifiedLanguageElement() {
		return fInherit.getBase();
	}

}
