package compositeRefactoring.codemanipulation;

import org.eclipse.jdt.core.IJavaModelStatus;
import org.eclipse.jdt.core.IType;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.jdt.internal.core.CreateMethodOperation;

/** This is a convenience class to make the CreateMethodOperation public.
 * The class creates an abstract method (no body).
 */
public class CreateAbstractMethod extends CreateMethodOperation {
	
	/** creates an object of CreateAbstractMethod. 
	 * @param parentType the type in which the method will be created.
	 * @param name the method's name.
	 * @param returnType the return type of the method.
	 * @param parameters the parameters of the method. The String array is supposed tp look like
	 * {"Object o", "int i", "String s"}.
	 * @param force indicates if an existing method should be overridden.<ul>
	 * <li><b>true</b> if an existing method should be overriden
	 * <li><b>false</b> if an existing method cancels the operation.</ul>
	 */
	public CreateAbstractMethod(IType parentType, String name, String returnType, 
							     String[] parameters, boolean force) {
		super(parentType, "", force);   	
		fSource = "\tpublic abstract " + returnType + " " + name + "(";
		for (int i = 0; i < parameters.length; i++) {
			fSource += parameters[i];
			if (!(i == parameters.length-1))
				fSource += ", ";
		}
		fSource += ");\n";		
		
	}
	/** verifies if the method can be created.
 	 * Possible failures: <ul>
	 *  <li>NO_ELEMENTS_TO_PROCESS - the parent element supplied to the operation is
	 * 		<code>null</code>.
	 *	<li>INVALID_CONTENTS - The source is <code>null</code> or has serious syntax errors.
	 *	<li>NAME_COLLISION - A name collision occurred in the destination
	 * </ul>
	 *@return the status of this verification\
	 */
	public IJavaModelStatus verify() {
		return super.verify();
	}
	/** creates the abstract method.
	 */
	public void executeOperation() {
		try {
			super.executeOperation();
		}
		catch(JavaModelException jme) {
			System.out.println(jme.getMessage());
			jme.printStackTrace();
		}
	}
}
