package compositeRefactoring.codemanipulation;

import org.eclipse.jdt.core.IJavaElement;
import org.eclipse.jdt.core.IJavaModelStatus;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.jdt.internal.core.CreateTypeOperation;

/** This is a convenience class to make the CreateTypeOperation public.
 * The class creates a class and a compilation unit. It can also be used
 * to create a new type within an existing type.
 */
public class CreateClass extends CreateTypeOperation {
	private IJavaElement fParentElement;
	// fSource and fForce are inherited.
	
	/** creates an object of CreateClass.
	 * @param parentElement the parent element of the new created class. This can be either 
	 * a compilation unit or a package or a type. (only compilation unit is tested!)
	 * @param source the source code for the new class (it must include the whole source code
	 * of the class, not only the body)
	 * @param force indicates if an existing class with the same name should be overridden
	 */
	public CreateClass(IJavaElement parentElement, String source, boolean force) {
		super(parentElement, source, force);
		fParentElement = parentElement;
		fSource = source;
		fForce = force;
	}
	
	/** verifies a name collision. Indicates if there is another element in this parent with the
	 * same name.
	 * @return the status of this verification
	 */
	public IJavaModelStatus verifyNameCollision() {
		return super.verifyNameCollision();
	}
	/** verifies whether a class can be created.
	 * Possible failures: <ul>
	 *  <li>NO_ELEMENTS_TO_PROCESS - the parent element supplied to the operation is
	 * 		<code>null</code>.
	 *	<li>INVALID_CONTENTS - The source is <code>null</code> or has serious syntax errors.
	 *	<li>NAME_COLLISION - A name collision occurred in the destination
	 * </ul>
	 * @return the status of this verification
	 */
	public IJavaModelStatus verify() {
		return super.verify();
	}
	/** creates the class
	 */
	public void executeOperation() {
		try {
			super.executeOperation();
		}
		catch(JavaModelException jme) {
			System.out.println(jme.getMessage());
			jme.printStackTrace();
		}
	}
}
