package compositeRefactoring.codemanipulation;

import org.eclipse.jdt.core.ICompilationUnit;
import org.eclipse.jdt.core.IJavaModelStatus;
import org.eclipse.jdt.core.IPackageFragment;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.jdt.internal.core.CreateCompilationUnitOperation;

/** This is a convenience class to make the CreateCompilatioinUnitOperation public.
 * The class creates a compilation unit (which represents a .java file). It can also be used
 * to create a new type by addinf sourcecode to the compilation unit.
 */
public class CreateCompilationUnit extends CreateCompilationUnitOperation {
	private IPackageFragment fParentElement;
	//fName, fSource and fForce are inherited and protected!
	
	/** creates a new CreateCompilationUnit object.
	 * @param parentElement the package in which the compilation unit is to be created.
	 * @param name the name of the compilation unit
	 * @param source the contents of the compilation unit
	 * @param force indicates whether an existing compilation unit with the same name shall be overridden.
	 */
	public CreateCompilationUnit(IPackageFragment parentElement, String name, String source, boolean force) {
		super(parentElement, name, source, force);
		fParentElement = parentElement;
		fName = name;
		fSource = source;
		fForce = force;
	}
	
	/** creates the compilation unit.
	 */
	public void executeOperation() {
		try {
			super.executeOperation();
		}
		catch(JavaModelException jme) {
			System.out.println(jme.getMessage());
			jme.printStackTrace();
		}
	}
	
	/** getter method for the new created compilation unit
	 * @return the new created compilation unit
	 */
	public ICompilationUnit getCompilationUnit() {
		return super.getCompilationUnit();
	}
	
	 /** checks whether a new compilation unit can be created.
	 * Possible failures: <ul>
	 *  <li>NO_ELEMENTS_TO_PROCESS - the package fragment supplied to the operation is
	 * 		<code>null</code>.
	 *	<li>INVALID_NAME - the compilation unit name provided to the operation 
	 * 		is <code>null</code> or has an invalid syntax
	 *  <li>INVALID_CONTENTS - the source specified for the compiliation unit is null
	 * </ul>
	 * NOTE: When this method is called, the source of the compilation unit must not be empty!
	 */
	public IJavaModelStatus verify() {
		return super.verify();
	}
}
