package compositeRefactoring.refactoringComposite;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.jdt.internal.corext.refactoring.base.IChange;
import org.eclipse.jdt.internal.corext.refactoring.base.RefactoringStatus;

/** this class is the superclass of all RefactoringComponents. A RefactoringComponent can be<ul>
 * <li>a RefactoringNode which is a single refactoring.
 * <li>a RefactoringComposite which is a set of RefactoringComponents.</ul>
 */
public abstract class RefactoringComponent {
	
	 protected String fName;
	 
	 /** creates a new RefactoringComponent object.
	  * @param name the name of the RefactoringComponent
	  */
	 RefactoringComponent(String name) {
	 	fName = name;
	 }
	
	 /** this method performs the refactoring. 
	  * @return the status of the performed refactoring.
	  */
	 public abstract RefactoringStatus refactor();
	 
	 /** this method undos the refactoring when it was performed.
	  * @return the status of the undo operation.
	  */
	 public abstract RefactoringStatus undo();
	 
	 /** gets the name of the RefactoringComponent
	  * @return the name of the RefactoringComponent.
	  */
	 public String getName() {
	 	return fName;
	 }
	 /** abstract method for checking the refactorings' enabling conditions
	  * @param pm the progress monitor to track the checks.
	  * @return the status of the check.
	  */
	 public abstract RefactoringStatus checkPreconditions(IProgressMonitor pm) throws JavaModelException;
	 /** abstract method for creating the code change of the refactoring
	  * @param pm the progress monitor to track the change.
	  * @return the change object of the refactoring.
	  */
	 public abstract IChange createChange(IProgressMonitor pm) throws JavaModelException;
}
