package compositeRefactoring.refactoringComposite;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.jdt.internal.corext.refactoring.CompositeChange;
import org.eclipse.jdt.internal.corext.refactoring.base.ChangeContext;
import org.eclipse.jdt.internal.corext.refactoring.base.IChange;
import org.eclipse.jdt.internal.corext.refactoring.base.IRefactoring;
import org.eclipse.jdt.internal.corext.refactoring.base.IUndoManager;
import org.eclipse.jdt.internal.corext.refactoring.base.Refactoring;
import org.eclipse.jdt.internal.corext.refactoring.base.RefactoringStatus;
import org.eclipse.jdt.internal.ui.refactoring.changes.ChangeExceptionHandler;

/** The RefactoringComposite class allows a client to merge single (low-level) refactorings to 
 * a higher-level refactoring. These refactorings are from type RefactoringComponent, e.g. they can 
 * either be a RefactoringNode (a single refactoring) or, recursively, another RefactoringComposite.
 */
public abstract class RefactoringComposite extends RefactoringComponent implements IRefactoring {

	public static final String DEFAULTNAME = "CompositeRefactoring";

	/** @see RefactoringComponent#refactor()
	 */
	public abstract RefactoringStatus refactor();
	/** @see RefactoringComponent#undo()
	 */
	public abstract RefactoringStatus undo();

	/** @see RefactoringComponent#checkPreconditions(IProgressMonitor pm)
	 */
	public abstract RefactoringStatus checkPreconditions(IProgressMonitor pm) throws JavaModelException;
	/** @see RefactoringComponent#createChange(IProgressMonitor pm)
	 */
	public abstract IChange createChange(IProgressMonitor pm) throws JavaModelException;
	
	/** creates a new RefactoringComposite object.
	 * @return the name of the refactoring
	 */
	RefactoringComposite(String name) {
		super(name);
	}
	 
}
