package compositeRefactoring.resources;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IFolder;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.IWorkspaceRoot;

import org.eclipse.jdt.core.ICompilationUnit;
import org.eclipse.jdt.core.IJavaElement;
import org.eclipse.jdt.core.IJavaModel;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jdt.core.IPackageFragment;
import org.eclipse.jdt.core.JavaCore;

/** GetJavaResources provides methods to fetch all relevant reources of a java project.
 */

public class GetJavaResources {
	
		private GetResources gcr;
		
		/** creates a new GetJavaResources object.
		 */
		public GetJavaResources() {
			gcr = new GetResources();
		}		
		
		/** gets a java project, the root of all java elements.
		 * @param proj the project file as stored on the filesystem.
		 * @return the java project
		 */
		public IJavaProject getJavaProject(IProject proj) {
			IWorkspaceRoot wsRoot= gcr.getWsRoot();
			IJavaModel jModel = JavaCore.create(wsRoot);
			IJavaProject jproj = null;
			jproj = jModel.getJavaProject(proj.getName());
			if (jproj == null) System.out.println("no Java project " + proj.getName() + " found.\n");
			//else System.out.println("Found JavaProject " + jproj.getElementName() + "\n");
			return jproj;
		}
		/** gets a java project, the root of all java elements.
		 * @param name the name of the java project.
		 * @return the java project
		 */
		public IJavaProject getJavaProject(String name) {
			IProject proj = gcr.getProject(name);
			return getJavaProject(proj);
		}
		
		/** gets a java package.
		 * @param folder the folder representing the package on the filesystem.
		 * @return the package fragment
		 */
		public IPackageFragment getJavaPackage(IFolder folder) {
			IJavaElement myElement = null;
			myElement = JavaCore.create(folder);
			IPackageFragment pack = (IPackageFragment) (myElement.getOpenable()); 
			if (pack == null) System.out.println("no Java package " + folder.getName() + " found.\n");
			//else System.out.println("Found Java Package " + pack.getElementName() + "\n");
			return pack;
		}
		/** gets a java package.
		 * @param projName the name of the project in which the java package is declared.
		 * @param name the name of the package.
		 * @return the package fragment
		 */
		public IPackageFragment getJavaPackage(String projName, String name) {
			IProject proj = gcr.getProject(projName);
			IFolder folder = gcr.getFolder(proj, name);
			return getJavaPackage(folder);
		}
		
		/** gets a compilation unit (a .java-file).
		 * @param file the underlying resource file of the compilation unit as stored on the filesystem.
		 * @return the java compilation unit.
		 */
		public ICompilationUnit getJavaCompilationUnit(IFile file) {
			ICompilationUnit compUnit = JavaCore.createCompilationUnitFrom(file);
			if (compUnit == null) System.out.println("no Java Compilation Unit " + file.getName() + " found.\n");
			//else System.out.println("Found Java Compilation Unit " + compUnit.getElementName() + "\n");
			return compUnit;
		}
		/** gets a compilation unit (a .java-file).
		 * @param projName the name of the project in which the .java-file is declared.
		 * @param name the name of the compilation unit.
		 * @return the java compilation unit.
		 */
		public ICompilationUnit getJavaCompilationUnit(String projName, String name) {
			IProject proj = gcr.getProject(projName);
			IFile myFile = gcr.getFile(proj, name);
			return getJavaCompilationUnit(myFile);
		}
		/** gets a compilation unit (a .java-file).
		 * @param projName the name of the project in which the .java-file is declared.
		 * @param folderName the name of the package in which the .java-file is declared.
		 * @param name the name of the compilation unit.
		 * @return the java compilation unit.
		 */
		public ICompilationUnit getJavaCompilationUnit(String projName, String folderName, String name) {
			IProject proj = gcr.getProject(projName);
			IFolder folder = gcr.getFolder(proj, folderName);
			IFile file = gcr.getFile(folder, name);
			return getJavaCompilationUnit(file);
		}
	
}
