package compositeRefactoring.resources;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IFolder;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;

/** GetResources provides some getter methods for fetching resource files of a Eclipse project.
 */
public class GetResources {
	
	private IWorkspaceRoot wsRoot;
	
	/** creates a new GetResources object.
	 */
	public GetResources() {
		wsRoot = ResourcesPlugin.getWorkspace().getRoot();		
	}
	/** gets the WorkspaceRoot of the Eclipse project.
	 * @return the WorkspaceRoot of the Eclipse project.
	 */
	public IWorkspaceRoot getWsRoot() {
		return wsRoot;
	}
	
	/** gets an Eclipse project by name.
	 * @param name the project's name.
	 * @return the Eclipse project.
	 */
	public IProject getProject(String name) {
		IProject proj = wsRoot.getProject(name);		
		if (proj.exists()) {
			 if(!(proj).isOpen()) {
				try {
					(proj).open(null);
				} catch (CoreException e) {
					e.printStackTrace();
				}
			 }
			 //DEBUG:
			 //System.out.println("Found project " +  name + "\n");
			 return proj;
		}
		else
		{
			System.out.println("no Project " + name + "\n");
			return null;
		}
	}
	
	/** gets a folder in an Eclipse project.
	 * @param proj the Eclipse project.
	 * @param name the foldername.
	 * @return the folder with the corresponding name.
	 */
	public IFolder getFolder(IProject proj, String name) {
		if(proj == null) 
			return null;
		IFolder myFolder = proj.getFolder(name);	
		if (myFolder.exists())	{
			//DEBUG:
			//System.out.println("Found folder " + name + "\n");
			return myFolder;
		}
		else
			return null;
	}
	/** gets a folder in a folder of an Eclipse project.
	 * @param folder the folder in which the folder is located in the filesystem.
	 * @param name the name of the folder.
	 * @return the folder with the corresponding name.
	 */
	public IFolder getFolder(IFolder folder, String name) {
		if (folder == null)
			return null;
		IFolder myFolder = folder.getFolder(name);
		if (myFolder.exists()) {
			return myFolder;
		}
		else
			return null;
	}			
	
	/** gets a file from a folder.
	 * @param folder the folder in which the file is located.
	 * @param name the file's name.
	 * @return the file with the corresponding name.
	 */
	public IFile getFile(IFolder folder, String name) {
		if (folder == null) 
			return null;
		IFile myFile = folder.getFile(name);
		if (myFile.exists()) {
			//DEBUG:
			//System.out.println("Found file " + name + "\n");
			return myFile;
		}
		else
			return null;
	}
	/** gets a file from an Eclipse project (top-level folder).
	 * @param folder the project in which the file is located.
	 * @param name the file's name.
	 * @return the file with the corresponding name.
	 */
	public IFile getFile(IProject folder, String name) {
		if (folder == null) 
			return null;
		IFile myFile = folder.getFile(name);
		if (myFile.exists()) {
			//DEBUG:
			//System.out.println("Found file " + name + "\n");
			return myFile;
		}
		else
			return null;
	}
}
